@@ -15,8 +15,18 @@ from ormar.fields import (
     Time,
 )
 from ormar.models import Model
+from ormar.queryset import QuerySet
+from ormar.relations import RelationType
 
-__version__ = "0.3.0"
+
+class UndefinedType:  # pragma no cover
+    def __repr__(self) -> str:
+        return "OrmarUndefined"
+
+
+Undefined = UndefinedType()
+
+__version__ = "0.3.1"
 __all__ = [
     "Integer",
     "BigInteger",
@@ -36,4 +46,7 @@ __all__ = [
     "MultipleMatches",
     "NoMatch",
     "ForeignKey",
+    "QuerySet",
+    "RelationType",
+    "Undefined",
 ]
